#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder
from enum import Enum

class ChangeLogEntryType(Enum):
	Created = 'Created';
	Updated = 'Updated';
	Deleted = 'Deleted';

class __ChangeLogEntryTypeSerDer__:
	def __init__( self):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ChangeLogEntryType[value]
		return instance


	def encode(self, value):
		if(value == None):
			return None
		instance = value.value
		return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class UserAccount :
	def __init__( self):
		self.login = None
		self.credentials = None
		self.additionalSettings = None
		pass

class __UserAccountSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = UserAccount()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		loginValue = value['login']
		instance.login = serder.STRING.parse(loginValue)
		credentialsValue = value['credentials']
		instance.credentials = serder.STRING.parse(credentialsValue)
		additionalSettingsValue = value['additionalSettings']
		instance.additionalSettings = serder.MapSerDer(serder.STRING).parse(additionalSettingsValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		loginValue = value.login
		instance["login"] = serder.STRING.encode(loginValue)
		credentialsValue = value.credentials
		instance["credentials"] = serder.STRING.encode(credentialsValue)
		additionalSettingsValue = value.additionalSettings
		instance["additionalSettings"] = serder.MapSerDer(serder.STRING).encode(additionalSettingsValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class JobExecutionQuery :
	def __init__( self):
		self.jobId = None
		self.domain = None
		self.id = None
		self.statuses = None
		self.active = None
		self.from_ = None
		self.size = None
		pass

class __JobExecutionQuerySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = JobExecutionQuery()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		jobIdValue = value['jobId']
		instance.jobId = serder.STRING.parse(jobIdValue)
		domainValue = value['domain']
		instance.domain = serder.STRING.parse(domainValue)
		idValue = value['id']
		instance.id = serder.INT.parse(idValue)
		from netbluemind.scheduledjob.api.JobExitStatus import JobExitStatus
		from netbluemind.scheduledjob.api.JobExitStatus import __JobExitStatusSerDer__
		statusesValue = value['statuses']
		instance.statuses = serder.SetSerDer(__JobExitStatusSerDer__()).parse(statusesValue)
		activeValue = value['active']
		instance.active = serder.BOOLEAN.parse(activeValue)
		from_Value = value['from']
		instance.from_ = serder.INT.parse(from_Value)
		sizeValue = value['size']
		instance.size = serder.INT.parse(sizeValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		jobIdValue = value.jobId
		instance["jobId"] = serder.STRING.encode(jobIdValue)
		domainValue = value.domain
		instance["domain"] = serder.STRING.encode(domainValue)
		idValue = value.id
		instance["id"] = serder.INT.encode(idValue)
		from netbluemind.scheduledjob.api.JobExitStatus import JobExitStatus
		from netbluemind.scheduledjob.api.JobExitStatus import __JobExitStatusSerDer__
		statusesValue = value.statuses
		instance["statuses"] = serder.SetSerDer(__JobExitStatusSerDer__()).encode(statusesValue)
		activeValue = value.active
		instance["active"] = serder.BOOLEAN.encode(activeValue)
		from_Value = value.from_
		instance["from"] = serder.INT.encode(from_Value)
		sizeValue = value.size
		instance["size"] = serder.INT.encode(sizeValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IResourceTypes_VERSION = "3.1.0.qualifier"

class IResourceTypes(BaseEndpoint):
	def __init__(self, apiKey, url ,domainUid ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/resources/{domainUid}/type'
		self.domainUid_ = domainUid
		self.base = self.base.replace('{domainUid}',domainUid)

	def update (self, uid , rt ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.resource.api.type.ResourceTypeDescriptor import ResourceTypeDescriptor
		from netbluemind.resource.api.type.ResourceTypeDescriptor import __ResourceTypeDescriptorSerDer__
		__data__ = __ResourceTypeDescriptorSerDer__().encode(rt)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResourceTypes_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def delete (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResourceTypes_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getIcon (self, uid ):
		postUri = "/{uid}/icon";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResourceTypes_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ByteArraySerDer, response)
	def setIcon (self, uid , icon ):
		postUri = "/{uid}/icon";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		__data__ = serder.ByteArraySerDer.encode(icon)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResourceTypes_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def get (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResourceTypes_VERSION}, data = json.dumps(__data__));
		from netbluemind.resource.api.type.ResourceTypeDescriptor import ResourceTypeDescriptor
		from netbluemind.resource.api.type.ResourceTypeDescriptor import __ResourceTypeDescriptorSerDer__
		return self.handleResult__(__ResourceTypeDescriptorSerDer__(), response)
	def create (self, identifier , rt ):
		postUri = "/{identifier}";
		__data__ = None
		postUri = postUri.replace("{identifier}",identifier);
		from netbluemind.resource.api.type.ResourceTypeDescriptor import ResourceTypeDescriptor
		from netbluemind.resource.api.type.ResourceTypeDescriptor import __ResourceTypeDescriptorSerDer__
		__data__ = __ResourceTypeDescriptorSerDer__().encode(rt)

		queryParams = {    };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResourceTypes_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getTypes (self):
		postUri = "";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IResourceTypes_VERSION}, data = json.dumps(__data__));
		from netbluemind.resource.api.type.ResourceType import ResourceType
		from netbluemind.resource.api.type.ResourceType import __ResourceTypeSerDer__
		return self.handleResult__(serder.ListSerDer(__ResourceTypeSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class CustomProperty :
	def __init__( self):
		self.name = None
		self.type = None
		self.size = None
		self.defaultValue = None
		self.globalAdminOnly = None
		self.translatedName = None
		pass

class __CustomPropertySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = CustomProperty()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		nameValue = value['name']
		instance.name = serder.STRING.parse(nameValue)
		from netbluemind.customproperties.api.CustomPropertyType import CustomPropertyType
		from netbluemind.customproperties.api.CustomPropertyType import __CustomPropertyTypeSerDer__
		typeValue = value['type']
		instance.type = __CustomPropertyTypeSerDer__().parse(typeValue)
		sizeValue = value['size']
		instance.size = serder.INT.parse(sizeValue)
		defaultValueValue = value['defaultValue']
		instance.defaultValue = serder.STRING.parse(defaultValueValue)
		globalAdminOnlyValue = value['globalAdminOnly']
		instance.globalAdminOnly = serder.BOOLEAN.parse(globalAdminOnlyValue)
		translatedNameValue = value['translatedName']
		instance.translatedName = serder.MapSerDer(serder.STRING).parse(translatedNameValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		nameValue = value.name
		instance["name"] = serder.STRING.encode(nameValue)
		from netbluemind.customproperties.api.CustomPropertyType import CustomPropertyType
		from netbluemind.customproperties.api.CustomPropertyType import __CustomPropertyTypeSerDer__
		typeValue = value.type
		instance["type"] = __CustomPropertyTypeSerDer__().encode(typeValue)
		sizeValue = value.size
		instance["size"] = serder.INT.encode(sizeValue)
		defaultValueValue = value.defaultValue
		instance["defaultValue"] = serder.STRING.encode(defaultValueValue)
		globalAdminOnlyValue = value.globalAdminOnly
		instance["globalAdminOnly"] = serder.BOOLEAN.encode(globalAdminOnlyValue)
		translatedNameValue = value.translatedName
		instance["translatedName"] = serder.MapSerDer(serder.STRING).encode(translatedNameValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.calendar.api.VEvent import VEvent
from netbluemind.calendar.api.VEvent import __VEventSerDer__
class VEventOccurrence (VEvent):
	def __init__( self):
		VEvent.__init__(self)
		self.recurid = None
		pass

class __VEventOccurrenceSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VEventOccurrence()
		__VEventSerDer__().parseInternal(value,instance)

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		recuridValue = value['recurid']
		instance.recurid = __BmDateTimeSerDer__().parse(recuridValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):
	 	__VEventSerDer__().encodeInternal(value,instance)

		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		recuridValue = value.recurid
		instance["recurid"] = __BmDateTimeSerDer__().encode(recuridValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IDevice_VERSION = "3.1.0.qualifier"

class IDevice(BaseEndpoint):
	def __init__(self, apiKey, url ,userUid ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/devices/{userUid}'
		self.userUid_ = userUid
		self.base = self.base.replace('{userUid}',userUid)

	def setPartnership (self, uid ):
		postUri = "/{uid}/_partnership";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDevice_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def deleteAll (self):
		postUri = "/_deleteAll";
		__data__ = None
		queryParams = {  };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDevice_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def update (self, uid , device ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.device.api.Device import Device
		from netbluemind.device.api.Device import __DeviceSerDer__
		__data__ = __DeviceSerDer__().encode(device)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDevice_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def list (self):
		postUri = "/_list";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDevice_VERSION}, data = json.dumps(__data__));
		from netbluemind.device.api.Device import Device
		from netbluemind.device.api.Device import __DeviceSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		from netbluemind.core.api.ListResult import ListResult
		from netbluemind.core.api.ListResult import __ListResultSerDer__
		return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__DeviceSerDer__())), response)
	def unwipe (self, uid ):
		postUri = "/_unwipe/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDevice_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def delete (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDevice_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def unsetPartnership (self, uid ):
		postUri = "/{uid}/_partnership";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDevice_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getComplete (self, uid ):
		postUri = "/{uid}/complete";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDevice_VERSION}, data = json.dumps(__data__));
		from netbluemind.device.api.Device import Device
		from netbluemind.device.api.Device import __DeviceSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__DeviceSerDer__()), response)
	def wipe (self, uid ):
		postUri = "/_wipe/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDevice_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def byIdentifier (self, identifier ):
		postUri = "/{identifier}/byIdentifier";
		__data__ = None
		postUri = postUri.replace("{identifier}",identifier);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDevice_VERSION}, data = json.dumps(__data__));
		from netbluemind.device.api.Device import Device
		from netbluemind.device.api.Device import __DeviceSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__DeviceSerDer__()), response)
	def create (self, uid , device ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.device.api.Device import Device
		from netbluemind.device.api.Device import __DeviceSerDer__
		__data__ = __DeviceSerDer__().encode(device)

		queryParams = {    };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDevice_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def updateLastSync (self, uid ):
		postUri = "/{uid}/_lastSync";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IDevice_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.icalendar.api.ICalendarElement import ICalendarElement
from netbluemind.icalendar.api.ICalendarElement import __ICalendarElementSerDer__
class VTodo (ICalendarElement):
	def __init__( self):
		ICalendarElement.__init__(self)
		self.due = None
		self.percent = None
		self.completed = None
		self.uid = None
		pass

class __VTodoSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = VTodo()
		__ICalendarElementSerDer__().parseInternal(value,instance)

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dueValue = value['due']
		instance.due = __BmDateTimeSerDer__().parse(dueValue)
		percentValue = value['percent']
		instance.percent = serder.INT.parse(percentValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		completedValue = value['completed']
		instance.completed = __BmDateTimeSerDer__().parse(completedValue)
		uidValue = value['uid']
		instance.uid = serder.STRING.parse(uidValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):
	 	__ICalendarElementSerDer__().encodeInternal(value,instance)

		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		dueValue = value.due
		instance["due"] = __BmDateTimeSerDer__().encode(dueValue)
		percentValue = value.percent
		instance["percent"] = serder.INT.encode(percentValue)
		from netbluemind.core.api.date.BmDateTime import BmDateTime
		from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
		completedValue = value.completed
		instance["completed"] = __BmDateTimeSerDer__().encode(completedValue)
		uidValue = value.uid
		instance["uid"] = serder.STRING.encode(uidValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IFolders_VERSION = "3.1.0.qualifier"

class IFolders(BaseEndpoint):
	def __init__(self, apiKey, url ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/ifolders'

	def byUid (self, uid ):
		postUri = "/by_uid";
		__data__ = None
		queryParams = {  'uid': uid   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IFolders_VERSION}, data = json.dumps(__data__));
		from netbluemind.folder.api.Folder import Folder
		from netbluemind.folder.api.Folder import __FolderSerDer__
		return self.handleResult__(__FolderSerDer__(), response)
	def byContentUri (self, uri ):
		postUri = "/by_uri";
		__data__ = None
		queryParams = {  'uri': uri   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IFolders_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.api.ListResult import ListResult
		from netbluemind.core.api.ListResult import __ListResultSerDer__
		return self.handleResult__(__ListResultSerDer__(serder.INT), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

ICustomTheme_VERSION = "3.1.0.qualifier"

class ICustomTheme(BaseEndpoint):
	def __init__(self, apiKey, url ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +''

	def setLogo (self, logo ):
		postUri = "/logo";
		__data__ = None
		__data__ = serder.ByteArraySerDer.encode(logo)

		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICustomTheme_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def getLogo (self):
		postUri = "/logo";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICustomTheme_VERSION}, data = json.dumps(__data__));
		from netbluemind.system.api.CustomLogo import CustomLogo
		from netbluemind.system.api.CustomLogo import __CustomLogoSerDer__
		return self.handleResult__(__CustomLogoSerDer__(), response)
	def deleteLogo (self):
		postUri = "/logo";
		__data__ = None
		queryParams = {  };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ICustomTheme_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

ITags_VERSION = "3.1.0.qualifier"

class ITags(BaseEndpoint):
	def __init__(self, apiKey, url ,containerUid ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/tags/{containerUid}'
		self.containerUid_ = containerUid
		self.base = self.base.replace('{containerUid}',containerUid)

	def all (self):
		postUri = "";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITags_VERSION}, data = json.dumps(__data__));
		from netbluemind.tag.api.Tag import Tag
		from netbluemind.tag.api.Tag import __TagSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__TagSerDer__())), response)
	def multipleGet (self, uids ):
		postUri = "/_mget";
		__data__ = None
		__data__ = serder.ListSerDer(serder.STRING).encode(uids)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITags_VERSION}, data = json.dumps(__data__));
		from netbluemind.tag.api.Tag import Tag
		from netbluemind.tag.api.Tag import __TagSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__TagSerDer__())), response)
	def allUids (self):
		postUri = "/_alluids";
		__data__ = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITags_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(serder.ListSerDer(serder.STRING), response)
	def changelog (self, since ):
		postUri = "/_changelog";
		__data__ = None
		queryParams = {  'since': since   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITags_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerChangelog import ContainerChangelog
		from netbluemind.core.container.model.ContainerChangelog import __ContainerChangelogSerDer__
		return self.handleResult__(__ContainerChangelogSerDer__(), response)
	def update (self, uid , tag ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.tag.api.Tag import Tag
		from netbluemind.tag.api.Tag import __TagSerDer__
		__data__ = __TagSerDer__().encode(tag)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITags_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def updates (self, changes ):
		postUri = "/_mupdates";
		__data__ = None
		from netbluemind.tag.api.TagChanges import TagChanges
		from netbluemind.tag.api.TagChanges import __TagChangesSerDer__
		__data__ = __TagChangesSerDer__().encode(changes)

		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITags_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerUpdatesResult import ContainerUpdatesResult
		from netbluemind.core.container.model.ContainerUpdatesResult import __ContainerUpdatesResultSerDer__
		return self.handleResult__(__ContainerUpdatesResultSerDer__(), response)
	def delete (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITags_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
	def changeset (self, since ):
		postUri = "/_changeset";
		__data__ = None
		queryParams = {  'since': since   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITags_VERSION}, data = json.dumps(__data__));
		from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
		from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
		return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)
	def getComplete (self, uid ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITags_VERSION}, data = json.dumps(__data__));
		from netbluemind.tag.api.Tag import Tag
		from netbluemind.tag.api.Tag import __TagSerDer__
		from netbluemind.core.container.model.ItemValue import ItemValue
		from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
		return self.handleResult__(__ItemValueSerDer__(__TagSerDer__()), response)
	def create (self, uid , tag ):
		postUri = "/{uid}";
		__data__ = None
		postUri = postUri.replace("{uid}",uid);
		from netbluemind.tag.api.Tag import Tag
		from netbluemind.tag.api.Tag import __TagSerDer__
		__data__ = __TagSerDer__().encode(tag)

		queryParams = {    };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : ITags_VERSION}, data = json.dumps(__data__));
		return self.handleResult__(None, response)
